package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.StUser;

/**
 * 用户7/30天统计数据Service接口
 * 
 * @author haotian
 * @date 2024-11-04
 */
public interface IStUserService 
{
    /**
     * 查询用户7/30天统计数据
     * 
     * @param userId 用户7/30天统计数据主键
     * @return 用户7/30天统计数据
     */
    public StUser selectStUserByUserId(Long userId);

    /**
     * 查询用户7/30天统计数据列表
     * 
     * @param stUser 用户7/30天统计数据
     * @return 用户7/30天统计数据集合
     */
    public List<StUser> selectStUserList(StUser stUser);

    /**
     * 新增用户7/30天统计数据
     * 
     * @param stUser 用户7/30天统计数据
     * @return 结果
     */
    public int insertStUser(StUser stUser);

    /**
     * 修改用户7/30天统计数据
     * 
     * @param stUser 用户7/30天统计数据
     * @return 结果
     */
    public int updateStUser(StUser stUser);

    /**
     * 批量删除用户7/30天统计数据
     * 
     * @param userIds 需要删除的用户7/30天统计数据主键集合
     * @return 结果
     */
    public int deleteStUserByUserIds(Long[] userIds);

    /**
     * 删除用户7/30天统计数据信息
     * 
     * @param userId 用户7/30天统计数据主键
     * @return 结果
     */
    public int deleteStUserByUserId(Long userId);
}
