package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StUser;
import com.ruoyi.system.service.IStUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户7/30天统计数据Controller
 * 
 * @author haotian
 * @date 2024-11-04
 */
@RestController
@RequestMapping("/system/userSt")
public class StUserController extends BaseController
{
    @Autowired
    private IStUserService stUserService;

    /**
     * 查询用户7/30天统计数据列表
     */
    @PreAuthorize("@ss.hasPermi('system:userSt:list')")
    @GetMapping("/list")
    public TableDataInfo list(StUser stUser)
    {
        startPage();
        List<StUser> list = stUserService.selectStUserList(stUser);
        return getDataTable(list);
    }

    /**
     * 导出用户7/30天统计数据列表
     */
    @PreAuthorize("@ss.hasPermi('system:userSt:export')")
    @Log(title = "用户7/30天统计数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StUser stUser)
    {
        List<StUser> list = stUserService.selectStUserList(stUser);
        ExcelUtil<StUser> util = new ExcelUtil<StUser>(StUser.class);
        util.exportExcel(response, list, "用户7/30天统计数据数据");
    }

    /**
     * 获取用户7/30天统计数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:userSt:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(stUserService.selectStUserByUserId(userId));
    }

    /**
     * 新增用户7/30天统计数据
     */
    @PreAuthorize("@ss.hasPermi('system:userSt:add')")
    @Log(title = "用户7/30天统计数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StUser stUser)
    {
        return toAjax(stUserService.insertStUser(stUser));
    }

    /**
     * 修改用户7/30天统计数据
     */
    @PreAuthorize("@ss.hasPermi('system:userSt:edit')")
    @Log(title = "用户7/30天统计数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StUser stUser)
    {
        return toAjax(stUserService.updateStUser(stUser));
    }

    /**
     * 删除用户7/30天统计数据
     */
    @PreAuthorize("@ss.hasPermi('system:userSt:remove')")
    @Log(title = "用户7/30天统计数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        return toAjax(stUserService.deleteStUserByUserIds(userIds));
    }
}
